@@ -1,3 +1,4 @@
+/* -*- mode:C; indent-tabs-mode:t; tab-width:8; c-basic-offset:8; -*- */
 /* gnome-netinfo - A GUI Interface for network utilities
  * Copyright (C) 2002 by German Poo-Caaman~o
  *
@@ -32,8 +33,10 @@ void netstat_multicast_tree_insert (GtkTreeView *widget, gchar *line);
 static gint strip_multicast_line (gchar * line, netstat_multicast_data *data);
 void netstat_create_multicast_model (GtkTreeView *widget);
 
+static NetstatOption netstat_get_active_option2 (Netinfo * netinfo);
+static gchar * netstat_get_active_option (Netinfo * netinfo);
+
 static GtkTreeModel *protocol_model, *route_model, *multicast_model;
-static GtkTreeView *protocol_view, *route_view, *multicast_view;
 
 void clean_gtk_tree_view (GtkTreeView *widget);
 
@@ -41,7 +44,8 @@ void clean_gtk_tree_view (GtkTreeView *widget);
  * the right GtkTreeModel
  */
 void
-on_protocol_button_toggled (GtkToggleButton *togglebutton, gpointer user_data) {
+on_protocol_button_toggled (GtkToggleButton *togglebutton, gpointer user_data)
+{
 	GtkTreeView *widget;
 	Netinfo *netinfo = user_data;
 	/* GtkWidget *parent, *child; */
@@ -77,10 +81,10 @@ on_protocol_button_toggled (GtkToggleButton *togglebutton, gpointer user_data) {
 	/* gtk_widget_unref (child); */
 }
 
-NetstatOption 
+static NetstatOption
 netstat_get_active_option2 (Netinfo * netinfo)
 {
-	NetstatOption  option;
+	NetstatOption option = NONE;
 	
 	g_return_val_if_fail (netinfo != NULL, ROUTE);
 	
@@ -96,7 +100,7 @@ netstat_get_active_option2 (Netinfo * netinfo)
 	return option;
 }
 
-gchar *
+static gchar *
 netstat_get_active_option (Netinfo * netinfo)
 {
 	gchar *option = NULL;
@@ -119,7 +123,8 @@ netstat_get_active_option (Netinfo * netinfo)
 }
 
 void
-netstat_stop (Netinfo * netinfo) {
+netstat_stop (Netinfo * netinfo)
+{
 	g_return_if_fail (netinfo != NULL);
 	
 	netinfo_stop_process_command (netinfo);
@@ -128,8 +133,6 @@ netstat_stop (Netinfo * netinfo) {
 void
 netstat_do (Netinfo * netinfo)
 {
-	GtkTextBuffer *buffer = NULL;
-	GtkTextIter start, end;
 	gchar *command = NULL;
 	gchar *option = NULL;
 	gchar *program = NULL;
@@ -145,21 +148,12 @@ netstat_do (Netinfo * netinfo)
 		gtk_list_store_clear (GTK_LIST_STORE (model));
 	}
 
-/*	buffer =
-	    gtk_text_view_get_buffer (GTK_TEXT_VIEW (netinfo->output));
-
-	gtk_text_buffer_get_start_iter (buffer, &start);
-	gtk_text_buffer_get_end_iter (buffer, &end);
-
-	gtk_text_buffer_delete (buffer, &start, &end);
-*/
 	parent = gtk_widget_get_toplevel (netinfo->output);
 	
 	program = util_find_program_dialog ("netstat", parent);
 
 	if (program != NULL) {
 		command =
-//			g_strdup_printf ("%s netstat %s", NETSTAT_PROGRAM, option);
 			g_strdup_printf ("%s netstat %s", program, option);
 	
 		netinfo->command_line = g_strsplit (command, " ", -1);
@@ -180,7 +174,6 @@ netstat_foreach (Netinfo * netinfo, gchar * line, gint len, gpointer user_data)
 {
 	gchar *text_utf8;
 	gssize bytes_written;
-	GtkWidget *entry = NULL;
 	GtkTextBuffer *buffer = NULL;
 	GtkTextIter iter;
 	
@@ -230,7 +223,7 @@ netstat_foreach (Netinfo * netinfo, gchar * line, gint len, gpointer user_data)
 */
 void
 netstat_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
-			gpointer user_data)
+			   gpointer user_data)
 {
 	GtkTreeView *widget;
 
@@ -251,20 +244,23 @@ netstat_foreach_with_tree (Netinfo * netinfo, gchar * line, gint len,
 		case MULTICAST:
 			netstat_multicast_tree_insert (widget, line);
 			break;
+		case NONE:
+		default:
+			break;
 		}
 	}
 }
 
 /* PROTOCOL */
 void
-netstat_protocol_tree_insert (GtkTreeView *widget, gchar *line) {
+netstat_protocol_tree_insert (GtkTreeView *widget, gchar *line)
+{
 	GtkTreeIter iter, sibling;
-	GList *columns;
+	/*GList *columns;*/
 	GtkTreePath *path;
 	GtkTreeModel *model;
 	gint count;
 	netstat_protocol_data data;
-	struct protoent *protocol = NULL;
 
 	g_return_if_fail (GTK_IS_TREE_VIEW (widget));
 	g_return_if_fail (line != NULL);
@@ -341,9 +337,9 @@ strip_protocol_line (gchar * line, netstat_protocol_data *data)
 	line = g_strdelimit (line, ":", ' ');
 
 	count = sscanf (line, NETSTAT_PROTOCOL_FORMAT,
-			&(data)->protocol, &n2, &n3,
-			&(data)->ip_src, &(data)->port_src, 
-			s6, s7, &(data)->state);
+			data->protocol, &n2, &n3,
+			data->ip_src, data->port_src, 
+			s6, s7, data->state);
 	
 	if (count == 7) {
 		bzero (&(data)->state, 30);
@@ -352,14 +348,13 @@ strip_protocol_line (gchar * line, netstat_protocol_data *data)
 	return count;
 }
 
-//static GtkTreeModel *
 void
 netstat_create_protocol_model (GtkTreeView *widget)
 {
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 
-//	clean_gtk_tree_view (widget);
+	/*clean_gtk_tree_view (widget);*/
 	
 	renderer = gtk_cell_renderer_text_new ();
 	/* Transport Protocol that runs over */
@@ -397,9 +392,10 @@ netstat_create_protocol_model (GtkTreeView *widget)
 
 /* ROUTE */
 void
-netstat_route_tree_insert (GtkTreeView *widget, gchar *line) {
+netstat_route_tree_insert (GtkTreeView *widget, gchar *line)
+{
 	GtkTreeIter iter, sibling;
-	GList *columns;
+	/*GList *columns;*/
 	GtkTreePath *path;
 	GtkTreeModel *model;
 	gint count;
@@ -479,10 +475,10 @@ strip_route_line (gchar * line, netstat_route_data *data)
 	gint ref, use;
 
 	count = sscanf (line, NETSTAT_ROUTE_FORMAT,
-			&(data)->destination,
-			&(data)->gateway, &(data)->netmask, 
+			data->destination,
+			data->gateway, data->netmask, 
 			flags, &(data)->metric, &ref, &use, 
-			&(data)->iface);
+			data->iface);
 	
 	return count;
 }
@@ -524,9 +520,10 @@ netstat_create_route_model (GtkTreeView *widget)
 
 /* MULTICAST */
 void
-netstat_multicast_tree_insert (GtkTreeView *widget, gchar *line) {
+netstat_multicast_tree_insert (GtkTreeView *widget, gchar *line)
+{
 	GtkTreeIter iter, sibling;
-	GList *columns;
+	/*GList *columns;*/
 	GtkTreePath *path;
 	GtkTreeModel *model;
 	gint count;
@@ -604,8 +601,8 @@ strip_multicast_line (gchar * line, netstat_multicast_data *data)
 	gint members;
 
 	count = sscanf (line, NETSTAT_MULTICAST_FORMAT,
-			&(data)->iface,
-			&members, &(data)->group);
+			data->iface,
+			&members, data->group);
 	snprintf ((data)->members, 30, "%d", members);
 	
 	return count;
@@ -644,7 +641,8 @@ netstat_create_multicast_model (GtkTreeView *widget)
 
 /* Remove all columns from a GtkTreeView */
 void
-clean_gtk_tree_view (GtkTreeView *widget) {
+clean_gtk_tree_view (GtkTreeView *widget)
+{
 	GList *columns, *list;
 	gint n, i;
 	GtkTreeViewColumn *column;
@@ -668,7 +666,6 @@ void
 netstat_copy_to_clipboard (Netinfo * netinfo, gpointer user_data)
 {
 	GString *result, *content;
-	NetstatOption option;
 
 	g_return_if_fail (netinfo != NULL);
 
@@ -692,6 +689,9 @@ netstat_copy_to_clipboard (Netinfo * netinfo, gpointer user_data)
 		   It's a tabular output, and these belongs to the column titles */
 		result = g_string_new (_("Interface\tMember\tGroup\n"));
 		break;
+	case NONE:
+	default:
+		break;
 	}
 
 	content = util_tree_model_to_string (GTK_TREE_VIEW (netinfo->output));
